@@ -23,7 +23,7 @@ import qibuild.parsers
 
 def configure_parser(parser):
     """Configure parser for this action."""
-    qibuild.parsers.build_parser(parser)
+    qibuild.parsers.cmake_build_parser(parser)
     qibuild.parsers.project_parser(parser)
     parser.add_argument("-z", dest="remove_known_configs", action="store_true",
                         help="remove all build directories that match a known configuration")
