@@ -18,7 +18,7 @@ SUPPORTED_IDES = ["QtCreator", "Visual Studio", "Xcode"]
 
 def configure_parser(parser):
     """Configure parser for this action """
-    qibuild.parsers.build_parser(parser)
+    qibuild.parsers.cmake_build_parser(parser)
     qibuild.parsers.project_parser(parser)
 
 def do(args):
