@@ -18,6 +18,9 @@ def configure_parser(parser):
     group = parser.add_argument_group("qisrc snapshot options")
     group.add_argument("snapshot_path", help="Path to the output snapshot file. " +
         "Use `qisrc reset --force --snapshot snapshot_path` to load a snapshot" )
+    group.add_argument("--deprecated-format", action="store_true",
+                       help="Only used for retro-compatibility")
+    parser.set_defaults(deprecated_format=False)
 
 
 def do(args):
@@ -25,4 +28,5 @@ def do(args):
     git_worktree = qisrc.parsers.get_git_worktree(args)
     ui.info(ui.green, "Current worktree:", ui.reset, ui.bold, git_worktree.root)
     snapshot_path = args.snapshot_path
-    qisrc.snapshot.generate_snapshot(git_worktree, snapshot_path)
+    qisrc.snapshot.generate_snapshot(git_worktree, snapshot_path,
+                                     deprecated_format=args.deprecated_format)
